package
Version:
v1.22.0
Opens a new window with list of versions in this module.
Published: Feb 24, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 1
Opens a new window with list of known importers.
README
¶
netHandler
netHandler provides network host reachability checking via ping.
Functions
| Function |
Description |
CheckHostAvailability(addr string) (bool, error) |
Pings a host (platform-aware) and returns whether it is reachable |
Example
import "github.com/mt1976/frantic-core/netHandler"
func main() {
available, err := netHandler.CheckHostAvailability("192.168.1.1")
if err != nil {
log.Fatal(err)
}
fmt.Println("Host available:", available)
}
Documentation
¶
Package netHandler provides HTTP/network helpers for client and server code.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.